@@ -1,16 +1,16 @@
+import asyncio
 from functools import partial
 from sys import platform
 from time import time
-import asyncio
 
-from pytest import mark
+from tqdm.asyncio import tarange, tqdm_asyncio
 
-from tqdm.asyncio import tqdm_asyncio, tarange
-from .tests_tqdm import StringIO, closing
+from .tests_tqdm import StringIO, closing, mark
 
 tqdm = partial(tqdm_asyncio, miniters=0, mininterval=0)
 trange = partial(tarange, miniters=0, mininterval=0)
 as_completed = partial(tqdm_asyncio.as_completed, miniters=0, mininterval=0)
+gather = partial(tqdm_asyncio.gather, miniters=0, mininterval=0)
 
 
 def count(start=0, step=1):
@@ -95,6 +95,7 @@ async def test_coroutines():
         assert '10it' in our_file.getvalue()
 
 
+@mark.slow
 @mark.asyncio
 @mark.parametrize("tol", [0.2 if platform.startswith("darwin") else 0.1])
 async def test_as_completed(capsys, tol):
@@ -112,3 +113,16 @@ async def test_as_completed(capsys, tol):
         except AssertionError:
             if retry == 2:
                 raise
+
+
+async def double(i):
+    return i * 2
+
+
+@mark.asyncio
+async def test_gather(capsys):
+    """Test asyncio gather"""
+    res = await gather(list(map(double, range(30))))
+    _, err = capsys.readouterr()
+    assert '30/30' in err
+    assert res == list(range(0, 30 * 2, 2))
